.. MeshParty documentation master file, created by
   sphinx-quickstart on Sun Aug 25 23:08:38 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MeshParty's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   includeme
   guide/loading
   guide/visualization
   guide/filtering
   guide/skeletons
   guide/repair
   guide/analysis

API
---
.. toctree::
   :maxdepth: 2
   :caption: Contents:

   source/meshparty

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
